@@ -3,7 +3,7 @@ from datetime import datetime
 import os
 import shutil
 
-import numpy
+import numpy as np
 import torch
 import torchvision
 from torch.utils.tensorboard import SummaryWriter
@@ -30,12 +30,12 @@ class Tensorboard():
         path = './runs/' if path is None else path
         path = f'{path}/' if '/' != path[-1] else path
 
-        if os.path.exists(path) is True and delete is True:
+        if os.path.exists(path) and delete:
             shutil.rmtree(f'{path}')
-        elif os.path.exists(path) is True and delete is False:
+        elif os.path.exists(path) and not delete:
             raise BoardAlreadyExistsException(path)
         else:
-            os.makedirs(path)
+            os.makedirs(path, exist_ok=True)
 
         if name is None:
             name = datetime.now()
@@ -112,7 +112,7 @@ class Tensorboard():
             raise Exception('Tensorboard: metrics should be a dictionary.')
         self.writer.add_hparams(hparams, metrics)
 
-    def add_image(self, prior, title, image, epoch=None):
+    def add_image(self, title, image, prior=None, epoch=None):
         """
         Add a single image data to summary.
 
@@ -127,11 +127,24 @@ class Tensorboard():
             It should be a string.
             Defualt: None.
         """
+        if not isinstance(prior, str) and prior is not None:
+            raise Exception('Tensorboard: prior should be a string or None.')
+        if not isinstance(title, str):
+            raise Exception('Tensorboard: title should be a string.')
+        if not isinstance(image, (torch.Tensor, np.ndarray)):
+            raise Exception('Tensorboard: title should be a Tensor or a Numpy Array.')
+
+        if len(image.shape) > 3:
+            raise Exception('Tensorboard: for more than one image use "add_grid"')
+        elif image.shape[0] not in [1, 3]:
+            raise Exception('Tensorboard: image should be of shape CxHxW.')
+
         epoch = self.epoch['default'] if epoch is None else self.epoch[epoch]
 
-        self.writer.add_image(f'{prior}/{title}', image, epoch)
+        name = f'{prior}/{title}' if prior is not None else title
+        self.writer.add_image(name, image, epoch)
 
-    def add_scalar(self, prior, title, value, epoch=None):
+    def add_scalar(self, title, value, epoch=None, prior=None):
         """
         Add a single scalar data to summary.
 
@@ -146,9 +159,19 @@ class Tensorboard():
             It should be a string.
             Defualt: None.
         """
+        if not isinstance(title, str):
+            raise Exception('Tensorboard: title should be a string.')
+        if not isinstance(value, (int, float, torch.Tensor)):
+            raise Exception('Tensorboard: value should be an int, float or torch.Tensor.')
+        if not isinstance(epoch, str) and epoch is not None:
+            raise Exception('Tensorboard: value should be a string or None.')
+        if not isinstance(prior, str) and prior is not None:
+            raise Exception('Tensorboard: prior should be a string or None.')
+
         epoch = self.epoch['default'] if epoch is None else self.epoch[epoch]
 
-        self.writer.add_scalar(f'{prior}/{title}', value, epoch)
+        name = f'{prior}/{title}' if prior is not None else title
+        self.writer.add_scalar(name, value, epoch)
 
     def add_scalars(self, prior, epoch=None, **kwargs):
         """
@@ -205,5 +228,5 @@ class Tensorboard():
         Add all histograms to summary at the end of an epoch.
         """
         for title in self.histograms:
-            self.writer.add_histogram(title, numpy.array(self.histograms[title]), self.epoch[epoch])
+            self.writer.add_histogram(title, np.array(self.histograms[title]), self.epoch[epoch])
 
